@@ -129,7 +129,7 @@ public class MenuBarMGraph extends JMenuBar implements ActionListener {
 		menu.add(makeMenuItem("Graph analysis", "graphAnalysis"));
 		//if (Configuration.getInstance().getGeneralConfig().experimentalFeatures()) {
 		menu.addSeparator();
-		menu.add(makeMenuItem("Power analysis", "powerAnalysis"));		
+		menu.add(makeMenuItem("Power analysis (experimental - will be improved soon)", "powerAnalysis"));		
 		//}
 
 		add(menu);
