@@ -317,11 +317,11 @@ public class NetList extends JPanel implements MouseMotionListener, MouseListene
 	public void mouseDragged(MouseEvent e) {
 		if (drag==-1 && edrag == -1) return;
 		if (drag!=-1) {
-			nodes.get(drag).setX( (int) ((e.getX() - Node.getRadius() * getZoom()) / (double) getZoom()));
-			nodes.get(drag).setY( (int) ((e.getY() - Node.getRadius() * getZoom()) / (double) getZoom()));
+			nodes.get(drag).setX( (int) ((e.getX()+offset[0]) / (double) getZoom()));
+			nodes.get(drag).setY( (int) ((e.getY()+offset[1]) / (double) getZoom()));
 		} else {
-			edges.get(edrag).setK1( (int) ((e.getX()) / (double) getZoom()));
-			edges.get(edrag).setK2( (int) ((e.getY()) / (double) getZoom()));
+			edges.get(edrag).setK1( (int) ((e.getX()+offset[0]) / (double) getZoom()));
+			edges.get(edrag).setK2( (int) ((e.getY()+offset[1]) / (double) getZoom()));
 		}
 		calculateSize();
 		repaint();
@@ -333,8 +333,10 @@ public class NetList extends JPanel implements MouseMotionListener, MouseListene
 
 	public void mouseMoved(MouseEvent e) {}
 
+	protected int[] offset;
+	
 	public void mousePressed(MouseEvent e) {
-		logger.debug("MousePressed at ("+e.getX()+","+ e.getY()+").");
+		//logger.debug("MousePressed at ("+e.getX()+","+ e.getY()+").");
 		if (newVertex) {
 			addDefaultNode((int)(e.getX() / getZoom()) - Node.r, 
 						(int) (e.getY() / getZoom()) - Node.r);
@@ -363,56 +365,42 @@ public class NetList extends JPanel implements MouseMotionListener, MouseListene
 			repaint();
 			return;
 		}
-		if (drag == -1) {
-			for (int i = 0; i < nodes.size(); i++) {
-				if (nodes.get(i).inYou(e.getX(), e.getY())) {
-					drag = i;
-					//statusBar.setText("Nr:" + knoten.get(i).nr + " Beschreibung:" + knoten.get(i).name);
-				}
-			}
-			if (drag != -1) {
-				nodes.get(drag).drag = true;
+
+		for (int i = 0; i < nodes.size(); i++) {
+			if (nodes.get(i).inYou(e.getX(), e.getY())) {
+				drag = i;
+				offset = nodes.get(i).offset(e.getX(), e.getY());
 			}
 		}
-		if (drag == -1 && edrag == -1) {
-			for (int i = 0; i < edges.size(); i++) {
-				if (edges.get(i).inYou(e.getX(), e.getY())) {
-					edrag = i;
-					//statusBar.setText("Nr:" + knoten.get(i).nr + " Beschreibung:" + knoten.get(i).name);
-				}
-			}		
-		}
-		if (e.getClickCount() == 2 && !testingStarted) {
-			for (int i = 0; i < nodes.size(); i++) {
-				if (nodes.get(i).inYou(e.getX(), e.getY())) {
-					new UpdateNode(nodes.get(i), this);
-				}
+		for (int i = edges.size()-1; i >=0 ; i--) {
+			if (edges.get(i).inYou(e.getX(), e.getY())) {
+				drag = -1;
+				edrag = i;
+				offset = edges.get(i).offset(e.getX(), e.getY());
 			}
-			for (int i = 0; i < edges.size(); i++) {
+		}
+		if (e.getClickCount() == 2 && !testingStarted) {			
+			for (int i = edges.size()-1; i >=0 ; i--) {
 				if (edges.get(i).inYou(e.getX(), e.getY())) {
 					new UpdateEdge(edges.get(i), this, control);
+					repaint();
+					return;
 				}
-			}		
+			}
+			for (int i = nodes.size()-1; i >=0 ; i--) {
+				if (nodes.get(i).inYou(e.getX(), e.getY())) {
+					new UpdateNode(nodes.get(i), this);
+					repaint();
+					return;
+				}
+			}
 		}		
 		repaint();
 	}
 	
 	public void mouseReleased(MouseEvent e) {
-		if (drag != -1) {
-			nodes.get(drag).setX( (int) ((e.getX() - Node.getRadius() * getZoom()) / (double) getZoom()));
-			nodes.get(drag).setY( (int) ((e.getY() - Node.getRadius() * getZoom()) / (double) getZoom()));
-			calculateSize();
-			nodes.get(drag).drag = false;
-			drag = -1;
-			repaint();
-		}
-		if (edrag != -1) {
-			edges.get(edrag).setK1( (int) ((e.getX()) / (double) getZoom()));
-			edges.get(edrag).setK2( (int) ((e.getY()) / (double) getZoom()));
-			calculateSize();
-			edrag = -1;
-			repaint();
-		}
+		drag = -1;
+		edrag = -1;
 	}
 	
 	/**
@@ -490,6 +478,7 @@ public class NetList extends JPanel implements MouseMotionListener, MouseListene
 	}
 	
 	public void removeEdge(Edge edge) {
+		logger.info("Removing "+edge);
 		for (Edge e : edges) {
 			if (e.from == edge.to && e.to == edge.from) {
 				e.curve = false;				
@@ -501,6 +490,7 @@ public class NetList extends JPanel implements MouseMotionListener, MouseListene
 	}
 
 	public void removeNode(Node node) {
+		logger.info("Removing "+node);		
 		for (int i=edges.size()-1; i>=0; i--) {
 			Edge e = edges.get(i);
 			if (e.from==node || e.to==node) {
@@ -518,6 +508,7 @@ public class NetList extends JPanel implements MouseMotionListener, MouseListene
 	}
 
 	public void reset() {
+		logger.info("Reset.");
 		edges.removeAllElements();
 		for (int i=getNodes().size()-1; i>=0; i--) {
 			removeNode(getNodes().get(i));
@@ -619,7 +610,7 @@ public class NetList extends JPanel implements MouseMotionListener, MouseListene
 		for (Edge e : edges) {				
 			RControl.getR().evalVoid("edgeAttr("+graphName+", \""+e.from.getName()+"\", \""+e.to.getName()+"\", \"labelX\") <- "+(e.k1-Node.getRadius()));
 			RControl.getR().evalVoid("edgeAttr("+graphName+", \""+e.from.getName()+"\", \""+e.to.getName()+"\", \"labelY\") <- "+(e.k2-Node.getRadius()));
-			logger.debug("Weight is: "+e.getW(ht));
+			//logger.debug("Weight is: "+e.getW(ht));
 			if (((Double)e.getW(ht)).isNaN()) {
 				RControl.getR().evalVoid("edgeAttr("+graphName+", \""+e.from.getName()+"\", \""+e.to.getName()+"\", \"variableWeight\") <- \""+e.getWS().replaceAll("\\\\", "\\\\\\\\")+"\"");
 			}
@@ -683,8 +674,8 @@ public class NetList extends JPanel implements MouseMotionListener, MouseListene
 	Double rejectAll = null;
 	Double userDefined = null;
 	
-	public void setPower(double[] localPower, double expRejections,
-			double powAtlst1, double rejectAll, double userDefined) {
+	public void setPower(double[] localPower, Double expRejections,
+			Double powAtlst1, Double rejectAll, Double userDefined) {
 		for (int i=0; i<localPower.length; i++) {
 			this.nodes.get(i).setLocalPower(localPower[i]);			
 		}
